@@ -582,7 +582,11 @@ long readData(char *ptr, long len, long pos)
 	i1 = pos & 0x000003ff;  //ȡ pos 10λ
 	i2 = i1 + (pos>>10);			//ȥ pos 10λ i1 
 
-	fread(ptr, 1, len, f);
+	size_t fread_size;
+	fread_size = fread(ptr, 1, len, f);
+	if (fread_size != (size_t)len) {
+		g_print("fread error!\n");
+	}
 
 	//²Ϊܹ
 	count = 0;
@@ -1140,7 +1144,6 @@ int
 main(int argc,char * argv [])
 {
 	setlocale(LC_ALL, "");
-	g_type_init ();
 	
 	convert();	
 	
